Index: c/src/lib/libbsp/a29k/portsw/startup/iface.c
===================================================================
--- c/src/lib/libbsp/a29k/portsw/startup/iface.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/a29k/portsw/startup/iface.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -20,5 +20,5 @@
      int nbytes)
 {
-    return __read(fd, buf, nbytes);
+    return __rtems_read(fd, buf, nbytes);
 }
 
@@ -28,5 +28,5 @@
       int nbytes)
 {
-    return __write(fd, buf, nbytes);
+    return __rtems_write(fd, buf, nbytes);
 }
 
@@ -36,5 +36,5 @@
      int mode)
 {
-    return __open(buf, flags, mode);
+    return __rtems_open(buf, flags, mode);
 }
 
@@ -42,5 +42,5 @@
 close(int fd)
 {
-    return __close(fd);
+    return __rtems_close(fd);
 }
 
@@ -52,5 +52,5 @@
 isatty(int fd)
 {
-    return __isatty(fd);
+    return __rtems_isatty(fd);
 }
 
@@ -64,5 +64,5 @@
       int whence)
 {
-    return __lseek(fd, offset, whence);
+    return __rtems_lseek(fd, offset, whence);
 }
 
@@ -75,5 +75,5 @@
       struct stat *buf)
 {
-    return __fstat(fd, buf);
+    return __rtems_fstat(fd, buf);
 }
 
@@ -81,5 +81,5 @@
 getpid()
 {
-  return __getpid();
+  return __rtems_getpid();
 }
 
@@ -91,5 +91,5 @@
      int sig)
 {
-    return __kill(pid, sig);
+    return __rtems_kill(pid, sig);
 }
 
Index: c/src/lib/libbsp/powerpc/papyrus/startup/linkcmds
===================================================================
--- c/src/lib/libbsp/powerpc/papyrus/startup/linkcmds	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/powerpc/papyrus/startup/linkcmds	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -22,4 +22,21 @@
 /* Do we need any of these for elf?
    __DYNAMIC = 0;    */
+
+/* What are these for? */
+
+__EXCEPT_START__ = 0;
+__EXCEPT_END__ = 0;
+__SDATA2_START__ = 0;
+__SDATA2_END__ = 0;
+__SBSS2_START__ = 0;
+__SBSS2_END__ = 0;
+__FIXUP_START__ = 0;
+__FIXUP_END__ = 0;
+__GOT2_START__ = 0;
+__GOT2_END__ = 0;
+__SDATA_START__ = 0;
+__SDATA_END__ = 0;
+
+
 SECTIONS
 {
@@ -38,4 +55,21 @@
      *(.descriptors)
      *(rom_ver)
+     etext = ALIGN(0x10);
+     _etext = .;
+     __CTOR_LIST__ = .;
+     LONG((__CTOR_END__ - __CTOR_LIST__) / 4 - 2)
+     *(.ctors)
+     LONG(0)
+     __CTOR_END__ = .;
+     __DTOR_LIST__ = .;
+     LONG((__DTOR_END__ - __DTOR_LIST__) / 4 - 2)
+     *(.dtors)
+     LONG(0)
+     __DTOR_END__ = .;
+     *(.lit)
+     *(.shdata)
+     *(.init)
+     *(.fini)
+     _endtext = .;
   } > RAM
  
@@ -47,4 +81,5 @@
   } > RAM
  
+  __GOT_START__ = .;
   .got :
   {
@@ -52,5 +87,7 @@
      *(.got.plt) *(.got)
   } > RAM
+  __GOT_END__ = .;
  
+  __SBSS_START__ = .;
   .bss :
   {
@@ -59,4 +96,5 @@
     bss.end = ALIGN(4);
   } > RAM
+  __SBSS_END__ = .;
  
   bss.size = bss.end - bss.start;
Index: c/src/lib/libbsp/a29k/portsw/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/a29k/portsw/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/a29k/portsw/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -86,5 +86,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
      *  calls for use by newlib (ie: provide __open, __close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
@@ -153,11 +153,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -86,5 +86,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
-     *  calls for use by newlib (ie: provide __open, __close, etc)
+     *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
Index: c/src/lib/libbsp/hppa1.1/simhppa/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/hppa1.1/simhppa/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/hppa1.1/simhppa/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -131,5 +131,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
      *  calls for use by newlib (ie: provide __open, __close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
@@ -246,11 +246,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -131,5 +131,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
-     *  calls for use by newlib (ie: provide __open, __close, etc)
+     *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
Index: c/src/lib/libbsp/i386/force386/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/i386/force386/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/i386/force386/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -61,5 +61,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
      *  calls for use by newlib (ie: provide __open, __close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
@@ -127,11 +127,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -61,5 +61,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
-     *  calls for use by newlib (ie: provide __open, __close, etc)
+     *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
Index: c/src/lib/libbsp/i386/go32/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/i386/go32/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/i386/go32/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -68,5 +68,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
      *  calls for use by newlib (ie: provide __open, __close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
@@ -134,11 +134,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -68,5 +68,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
-     *  calls for use by newlib (ie: provide __open, __close, etc)
+     *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
Index: c/src/lib/libbsp/i386/i386ex/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/i386/i386ex/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/i386/i386ex/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -62,5 +62,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
      *  calls for use by newlib (ie: provide __open, __close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
@@ -128,11 +128,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -62,5 +62,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
-     *  calls for use by newlib (ie: provide __open, __close, etc)
+     *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
Index: c/src/lib/libbsp/i960/cvme961/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/i960/cvme961/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/i960/cvme961/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -63,5 +63,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
      *  calls for use by newlib (ie: provide __open, __close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
@@ -129,11 +129,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -63,5 +63,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
-     *  calls for use by newlib (ie: provide __open, __close, etc)
+     *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
Index: c/src/lib/libbsp/m68k/dmv152/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/m68k/dmv152/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/m68k/dmv152/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -61,5 +61,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
      *  calls for use by newlib (ie: provide __open, __close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
@@ -127,11 +127,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -61,5 +61,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
-     *  calls for use by newlib (ie: provide __open, __close, etc)
+     *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
Index: c/src/lib/libbsp/m68k/efi332/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/m68k/efi332/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/m68k/efi332/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -61,5 +61,5 @@
   /*
    *  Init the RTEMS libio facility to provide UNIX-like system
    *  calls for use by newlib (ie: provide __open, __close, etc)
    *  Uses malloc() to get area for the iops, so must be after malloc init
    */
@@ -127,11 +127,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -61,5 +61,5 @@
   /*
    *  Init the RTEMS libio facility to provide UNIX-like system
-   *  calls for use by newlib (ie: provide __open, __close, etc)
+   *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
    *  Uses malloc() to get area for the iops, so must be after malloc init
    */
Index: c/src/lib/libbsp/m68k/efi68k/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/m68k/efi68k/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/m68k/efi68k/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -67,5 +67,5 @@
   /*
    *  Init the RTEMS libio facility to provide UNIX-like system
    *  calls for use by newlib (ie: provide __open, __close, etc)
    *  Uses malloc() to get area for the iops, so must be after malloc init
    */
@@ -134,11 +134,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -67,5 +67,5 @@
   /*
    *  Init the RTEMS libio facility to provide UNIX-like system
-   *  calls for use by newlib (ie: provide __open, __close, etc)
+   *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
    *  Uses malloc() to get area for the iops, so must be after malloc init
    */
Index: c/src/lib/libbsp/m68k/gen68302/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/m68k/gen68302/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/m68k/gen68302/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -69,5 +69,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
      *  calls for use by newlib (ie: provide __open, __close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
@@ -135,11 +135,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -69,5 +69,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
-     *  calls for use by newlib (ie: provide __open, __close, etc)
+     *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
Index: c/src/lib/libbsp/m68k/gen68360/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/m68k/gen68360/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/m68k/gen68360/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -65,5 +65,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
      *  calls for use by newlib (ie: provide __open, __close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
@@ -131,11 +131,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -65,5 +65,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
-     *  calls for use by newlib (ie: provide __open, __close, etc)
+     *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
Index: c/src/lib/libbsp/m68k/idp/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/m68k/idp/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/m68k/idp/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -70,5 +70,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
      *  calls for use by newlib (ie: provide __open, __close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
@@ -136,11 +136,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -70,5 +70,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
-     *  calls for use by newlib (ie: provide __open, __close, etc)
+     *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
Index: c/src/lib/libbsp/m68k/mvme136/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/m68k/mvme136/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/m68k/mvme136/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -63,5 +63,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
      *  calls for use by newlib (ie: provide __open, __close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
@@ -129,11 +129,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -63,5 +63,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
-     *  calls for use by newlib (ie: provide __open, __close, etc)
+     *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
Index: c/src/lib/libbsp/m68k/mvme147/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/m68k/mvme147/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/m68k/mvme147/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -66,5 +66,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
      *  calls for use by newlib (ie: provide __open, __close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
@@ -132,11 +132,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -66,5 +66,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
-     *  calls for use by newlib (ie: provide __open, __close, etc)
+     *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
Index: c/src/lib/libbsp/m68k/mvme147s/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/m68k/mvme147s/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/m68k/mvme147s/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -66,5 +66,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
      *  calls for use by newlib (ie: provide __open, __close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
@@ -132,11 +132,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -66,5 +66,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
-     *  calls for use by newlib (ie: provide __open, __close, etc)
+     *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
Index: c/src/lib/libbsp/m68k/mvme162/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/m68k/mvme162/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/m68k/mvme162/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -69,5 +69,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
      *  calls for use by newlib (ie: provide __open, __close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
@@ -135,11 +135,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -69,5 +69,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
-     *  calls for use by newlib (ie: provide __open, __close, etc)
+     *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
Index: c/src/lib/libbsp/no_cpu/no_bsp/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/no_cpu/no_bsp/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/no_cpu/no_bsp/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -70,5 +70,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
      *  calls for use by newlib (ie: provide __open, __close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
@@ -136,11 +136,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -70,5 +70,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
-     *  calls for use by newlib (ie: provide __open, __close, etc)
+     *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
Index: c/src/lib/libbsp/powerpc/papyrus/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/powerpc/papyrus/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/powerpc/papyrus/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -87,5 +87,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
      *  calls for use by newlib (ie: provide __open, __close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
@@ -154,11 +154,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -87,5 +87,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
-     *  calls for use by newlib (ie: provide __open, __close, etc)
+     *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
Index: c/src/lib/libbsp/unix/posix/startup/bspstart.c
===================================================================
--- c/src/lib/libbsp/unix/posix/startup/bspstart.c	(revision 2f933718b5122c314a01035d8120c845bc009a44)
+++ c/src/lib/libbsp/unix/posix/startup/bspstart.c	(revision 634e746544cc226ef388880bb1d3ec0144ff29db)
@@ -109,5 +109,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
      *  calls for use by newlib (ie: provide __open, __close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
@@ -188,11 +188,11 @@
   error_code = 'S' << 24 | 'T' << 16;
  
-  if ((stdin_fd = __open("/dev/console", O_RDONLY, 0)) == -1)
+  if ((stdin_fd = __rtems_open("/dev/console", O_RDONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '0' );
  
-  if ((stdout_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stdout_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '1' );
  
-  if ((stderr_fd = __open("/dev/console", O_WRONLY, 0)) == -1)
+  if ((stderr_fd = __rtems_open("/dev/console", O_WRONLY, 0)) == -1)
     rtems_fatal_error_occurred( error_code | 'D' << 8 | '2' );
  
@@ -109,5 +109,5 @@
     /*
      *  Init the RTEMS libio facility to provide UNIX-like system
-     *  calls for use by newlib (ie: provide __open, __close, etc)
+     *  calls for use by newlib (ie: provide __rtems_open, __rtems_close, etc)
      *  Uses malloc() to get area for the iops, so must be after malloc init
      */
